pub struct LibraryStats {
pub total_files: i64,
pub total_size_bytes: i64,
pub total_photos: i64,
pub total_videos: i64,
pub duplicate_group_count: i64,
pub duplicate_file_count: i64,
pub wasted_bytes: i64,
pub faces_detected: i64,
pub people_named: i64,
pub embeddings: Vec<ModelEmbeddingCount>,
}Fields
total_files: i64total_size_bytes: i64total_photos: i64total_videos: i64duplicate_group_count: i64duplicate_file_count: i64wasted_bytes: i64faces_detected: i64people_named: i64embeddings: Vec<ModelEmbeddingCount>One entry per model with an embedding database for this library. Empty when nothing has been embedded, which is a normal state.